#!/usr/bin/env python3

import subprocess
import sys
from colored import fg, bg, attr

reset_color = attr('reset')
ok_color = bg('black') + fg('green')
warn_color = bg('black') + fg('yellow')
err_color = bg('red') + fg('white')

def main():
    median()
    avg()

def median():
    cases = [
        ('icon-256x256.png', '[0, 0, 0, 255]'),
        ('colour.png', '[255, 0, 0, 255]'),
        ('palette.png', '[255, 153, 153, 255]'),
        ('ramp.png', '[0, 0, 0, 255]'),
        ('test.png', '[35, 38, 39, 255]'),
    ]

    run("./median_colour_working.py", cases)
    run("./median_colour_buggy.py", cases)
    print("")

def avg():
    cases = [
        ('icon-256x256.png', '[119, 115, 115, 249]'),
        ('colour.png', '[64, 64, 64, 255]'),
        ('palette.png', '[170, 119, 119, 255]'),
        ('ramp.png', '[127, 127, 127, 255]'),
        ('test.png', '[53, 42, 40, 255]'),
    ]

    run("./avg_colour_working.py", cases)
    run("./avg_colour_buggy.py", cases)
    print("")

def run(program, cases):
    print("\n{}testing {}{}".format(warn_color, program, reset_color))
    for case in cases:
        filename = case[0]
        expected = "{}: {}".format(filename, case[1])

        result = subprocess.run([program, filename], capture_output=True)
        output = result.stdout.decode("utf-8").strip()

        if output == expected:
            print("  {}  {} ok  {}".format(ok_color, filename, reset_color))
        else:
            print("  {}  {} ERROR  {}\n    expected: {}{}{}\n    received: {}{}{}\n"
                .format(err_color, filename, reset_color, 
                        warn_color, expected, reset_color, 
                        err_color, output, reset_color))



if __name__ == '__main__':
    main()
